@@ -57,6 +57,15 @@ gboolean disable_uninstalled = FALSE;
 gboolean ignore_requires = FALSE;
 gboolean ignore_private_libs = TRUE;
 
+static Package pkg_config_package = {
+  .key = PACKAGE,
+  .name = PACKAGE,
+  .version = VERSION, /* .version */
+  .description = "returns metainformation about installed libraries",
+  .url = "http://pkg-config.freedesktop.org",
+  0 /* keep the rest as null */
+};
+
 void
 add_search_dir (const char *path)
 {
@@ -179,7 +188,7 @@ scan_dir (const char *dirname)
 
       if (ends_in_dotpc (dent->d_name))
         {
-          char *pkgname = malloc (len - 2);
+          char *pkgname = g_malloc (len - 2);
 
           debug_spew ("File '%s' appears to be a .pc file\n", dent->d_name);
           
@@ -275,6 +284,9 @@ internal_get_package (const char *name, gboolean warn, gboolean check_compat)
   Package *pkg = NULL;
   const char *location;
   
+  if (strcmp(PACKAGE, name) == 0)
+    return &pkg_config_package;
+
   pkg = g_hash_table_lookup (packages, name);
 
   if (pkg)
@@ -605,7 +617,7 @@ recursive_fill_list (Package *pkg, GetListFunc func, GSList **listp)
 
   fill_one_level (pkg, func, listp);
   
-  tmp = pkg->requires;
+  tmp = (*func) (pkg);
 
   while (tmp != NULL)
     {
@@ -1139,14 +1151,14 @@ char *
 packages_get_I_cflags (GSList     *pkgs)
 {
   /* sort by path position so PKG_CONFIG_PATH affects -I flag order */
-  return get_multi_merged (pkgs, get_I_cflags, TRUE, FALSE);
+  return get_multi_merged (pkgs, get_I_cflags, TRUE, TRUE);
 }
 
 char *
 package_get_other_cflags (Package *pkg)
 {
   if (pkg->other_cflags_merged == NULL)
-    pkg->other_cflags_merged = get_merged (pkg, get_other_cflags, TRUE, FALSE);
+    pkg->other_cflags_merged = get_merged (pkg, get_other_cflags, TRUE, TRUE);
 
   return pkg->other_cflags_merged;
 }
@@ -1154,7 +1166,7 @@ package_get_other_cflags (Package *pkg)
 char *
 packages_get_other_cflags (GSList *pkgs)
 {
-  return get_multi_merged (pkgs, get_other_cflags, TRUE, FALSE);
+  return get_multi_merged (pkgs, get_other_cflags, TRUE, TRUE);
 }
 
 char *
